pm4py.algo.discovery.performance\_spectrum package
==================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.discovery.performance_spectrum.variants

Submodules
----------

pm4py.algo.discovery.performance\_spectrum.algorithm module
-----------------------------------------------------------

.. automodule:: pm4py.algo.discovery.performance_spectrum.algorithm
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.performance\_spectrum.outputs module
---------------------------------------------------------

.. automodule:: pm4py.algo.discovery.performance_spectrum.outputs
   :members:
   :undoc-members:
   :show-inheritance:

pm4py.algo.discovery.performance\_spectrum.parameters module
------------------------------------------------------------

.. automodule:: pm4py.algo.discovery.performance_spectrum.parameters
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.algo.discovery.performance_spectrum
   :members:
   :undoc-members:
   :show-inheritance:
